"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.contextMiddleware = contextMiddleware;
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const auth_1 = require("../auth");
const locale_1 = require("../locale");
const http_auth_1 = require("./http-auth");
const http_handler_1 = require("./http-handler");
function contextMiddleware(req, res, next) {
    const headers = {
        get: (key) => req.get(key),
        localeCode: req.get('accept-language') || req.get('content-language') || req.get('language') || locale_1.LocaleCode.EN_US,
        roleType: req.get('x-role-type'),
        remoteIp: (0, http_handler_1.getIp)(req),
        userAgent: req.get('user-agent'),
        userAgentPlatform: req.get('sec-ch-ua-platform'),
        userAgentClientHints: req.get('sec-ch-ua'),
        operatorId: req.get('x-operator-id')
    };
    const requestMetadata = req.get('x-metadata');
    if (requestMetadata) {
        try {
            const { error, value } = auth_1.schemaRequestMetadata.validate(JSON.parse(requestMetadata));
            if (error) {
                throw error;
            }
            headers.metadata = value;
        }
        catch (error) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_FORMAT, error.message, {
                function: 'contextMiddleware',
                details: error.details,
                text: { input: error.details?.[0]?.context?.peers || error.details?.[0]?.context?.key }
            });
        }
    }
    const info = {
        token: req.get('authorization'),
        ability: (0, auth_1.generateAbility)(),
        headers
    };
    (0, http_auth_1.setAuthToken)(req, { type: null, info });
    return next();
}
//# sourceMappingURL=http-context.js.map