import { PrismaClient } from '@prisma/client';
import Joi from 'joi';
import { AccessInfo } from '../auth';
import { BaseModel, BaseModelBrowseArgs, BaseModelBrowseReturn } from '../model';
type Service = {
    entityName: string;
    model: any;
    schemaBrowse: Joi.ObjectSchema;
    schemaRead: Joi.ObjectSchema;
    schemaEdit: Joi.ObjectSchema;
    schemaAdd: Joi.ObjectSchema;
    schemaDelete: Joi.ObjectSchema;
    schemaActivate: Joi.ObjectSchema;
    schemaDeactivate: Joi.ObjectSchema;
    auditTrail?: boolean;
    auditTrailAttrs?: string[];
    autoCacheIdForResolver?: boolean;
};
export declare enum MutationAction {
    ADD = "add",
    EDIT = "edit",
    ACTIVATE = "activate",
    DEACTIVATE = "deactivate"
}
export type RecordConfig = {
    remark?: string;
    includeInactive?: boolean;
    transaction?: Omit<PrismaClient, '$connect' | '$disconnect' | '$on' | '$transaction' | '$use' | '$extends'>;
};
export type NoInput = Record<string, never>;
export declare class BaseService<T, Browse, Read, Edit, Add, Delete, Activate, Deactivate> {
    readonly BASE_SERVICE_LOG: boolean;
    readonly BASE_SERVICE_FILTER_ORG: boolean;
    protected readonly entityName: string;
    readonly model: BaseModel<T, PrismaClient, PrismaClient, BaseModelBrowseArgs> & {
        instance: BaseModel<T, PrismaClient, PrismaClient, BaseModelBrowseArgs>;
    };
    readonly schemaBrowse: Joi.ObjectSchema;
    readonly schemaRead: Joi.ObjectSchema;
    readonly schemaEdit: Joi.ObjectSchema;
    readonly schemaAdd: Joi.ObjectSchema;
    readonly schemaDelete: Joi.ObjectSchema;
    readonly schemaActivate: Joi.ObjectSchema;
    readonly schemaDeactivate: Joi.ObjectSchema;
    readonly auditTrail: boolean;
    readonly auditTrailAttrs: string[];
    readonly autoCacheIdForResolver: boolean;
    readonly schemaNoInput: Joi.ObjectSchema;
    readonly selective: object;
    constructor({ entityName, model, schemaBrowse, schemaRead, schemaEdit, schemaAdd, schemaDelete, schemaActivate, schemaDeactivate, auditTrail, autoCacheIdForResolver, auditTrailAttrs }: Service);
    protected filterOrganization(_params: Browse | Read | Edit | Delete | Activate | Deactivate, _accessInfo: AccessInfo): void;
    protected filterRecordStatus(_params: Browse | Read | Edit | Delete | Activate | Deactivate, _accessInfo: AccessInfo): void;
    browse<R = T>(params: Browse, accessInfo: AccessInfo, config?: RecordConfig): Promise<BaseModelBrowseReturn<R>>;
    read<R = T>(params: Read, accessInfo: AccessInfo, config?: RecordConfig): Promise<R>;
    edit<R = T>(params: Edit, accessInfo: AccessInfo, config?: RecordConfig): Promise<R>;
    add<R = T>(params: Add, accessInfo: AccessInfo, config?: RecordConfig): Promise<R>;
    delete<R = T>(params: Delete, accessInfo: AccessInfo, config?: RecordConfig): Promise<R>;
    activate<R = T>(params: Activate, accessInfo: AccessInfo, config?: RecordConfig): Promise<R>;
    deactivate<R = T>(params: Deactivate, accessInfo: AccessInfo, config?: RecordConfig): Promise<R>;
}
export declare class BaseServiceEx<T, Browse, Read, Edit, Add, Delete, Activate, Deactivate> extends BaseService<T, Browse, Read, Edit, Add, Delete, Activate, Deactivate> {
    protected filterOrganization(_params: Browse | Read | Edit | Delete | Activate | Deactivate, _accessInfo: AccessInfo): void;
    protected filterRecordStatus(_params: Browse | Read | Edit | Delete | Activate | Deactivate, _accessInfo: AccessInfo): void;
    activate<R = T>(params: Activate, accessInfo: AccessInfo, config?: RecordConfig): Promise<R>;
    deactivate<R = T>(params: Deactivate, accessInfo: AccessInfo, config?: RecordConfig): Promise<R>;
}
export {};
